@@ -14,9 +14,23 @@
 
 from selenium import webdriver
 
+from appium.common.helper import extract_const_attributes
+from appium.common.logger import logger
 from appium.webdriver.mobilecommand import MobileCommand as Command
 
 
+class NetSpeed(object):
+    GSM = 'gsm'  # GSM/CSD (up: 14.4(kbps), down: 14.4(kbps))
+    SCSD = 'scsd'  # HSCSD (up: 14.4, down: 57.6)
+    GPRS = 'gprs'  # GPRS (up: 28.8, down: 57.6)
+    EDGE = 'edge'  # EDGE/EGPRS (up: 473.6, down: 473.6)
+    UMTS = 'umts'  # UMTS/3G (up: 384.0, down: 384.0)
+    HSDPA = 'hsdpa'  # HSDPA (up: 5760.0, down: 13,980.0)
+    LTE = 'lte'  # LTE (up: 58,000, down: 173,000)
+    EVDO = 'evdo'  # EVDO (up: 75,000, down: 280,000)
+    FULL = 'full'  # No limit, the default (up: 0.0, down: 0.0)
+
+
 class Network(webdriver.Remote):
 
     @property
@@ -40,7 +54,7 @@ class Network(webdriver.Remote):
         These are available through the enumeration `appium.webdriver.ConnectionType`
 
         :Args:
-         - connectionType - a member of the enum appium.webdriver.ConnectionType
+         - connection_type - a member of the enum appium.webdriver.ConnectionType
         """
         data = {
             'parameters': {
@@ -55,6 +69,25 @@ class Network(webdriver.Remote):
         self.execute(Command.TOGGLE_WIFI, {})
         return self
 
+    def set_network_speed(self, speed_type):
+        """Set the network speed emulation.
+        Android Emulator only.
+
+        :Args:
+         - speed_type (str): The network speed type.
+           A member of the const appium.webdriver.extensions.android.network.NetSpeed.
+
+        :Usage:
+            self.driver.set_network_speed(NetSpeed.LTE)
+        """
+        constants = extract_const_attributes(NetSpeed)
+        if speed_type not in constants.values():
+            logger.warning('{} is unknown. Consider using one of {} constants. (e.g. {}.LTE)'.format(
+                speed_type, list(constants.keys()), NetSpeed.__name__))
+
+        self.execute(Command.SET_NETWORK_SPEED, {'netspeed': speed_type})
+        return self
+
     # pylint: disable=protected-access
 
     def _addCommands(self):
@@ -64,3 +97,5 @@ class Network(webdriver.Remote):
             ('GET', '/session/$sessionId/network_connection')
         self.command_executor._commands[Command.SET_NETWORK_CONNECTION] = \
             ('POST', '/session/$sessionId/network_connection')
+        self.command_executor._commands[Command.SET_NETWORK_SPEED] = \
+            ('POST', '/session/$sessionId/appium/device/network_speed')
