@@ -12,12 +12,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import json
+
 from selenium.webdriver.common.by import By
-from selenium.webdriver.remote.webelement import WebElement as SeleniumWebElement
 from selenium.webdriver.remote.command import Command as RemoteCommand
 
 from appium.webdriver.common.mobileby import MobileBy
 
+from .extensions.search_context import AppiumWebElementSearchContext
 from .mobilecommand import MobileCommand as Command
 
 # Python 3 imports
@@ -27,7 +29,7 @@ except NameError:
     pass
 
 
-class WebElement(SeleniumWebElement):
+class WebElement(AppiumWebElementSearchContext):
     # Override
     def get_attribute(self, name):
         """Gets the given attribute or property of the element.
